==> ejc-zhengyuan-impl-3.0.0-20250821.081133-43-sources.jar: com/ejianc/business/prjdocs/vo/PrjInvestResourceRequirePlanEquipmentVO.java <==
package com.ejianc.business.prjdocs.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 投入资源需求计划--设备计划
 * 
 * @author generator
 * 
 */
public class PrjInvestResourceRequirePlanEquipmentVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long pid; // 父id
    private Long equipmentId; // 设备id
    private String equipmentName; // 设备名称
    private Integer equipmentNumber; // 设备数量
    private Date arrivalTime; // 到位时间
    private String otherExplain; // 其他说明

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }

    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public Integer getEquipmentNumber() {
        return equipmentNumber;
    }

    public void setEquipmentNumber(Integer equipmentNumber) {
        this.equipmentNumber = equipmentNumber;
    }
    public Date getArrivalTime() {
        return arrivalTime;
    }

    public void setArrivalTime(Date arrivalTime) {
        this.arrivalTime = arrivalTime;
    }
    public String getOtherExplain() {
        return otherExplain;
    }

    public void setOtherExplain(String otherExplain) {
        this.otherExplain = otherExplain;
    }
    
}

==> ejc-zhengyuan-impl-3.0.0-20251202.033713-51-sources.jar: com/ejianc/business/prjdocs/vo/PrjInvestResourceRequirePlanEquipmentVO.java <==
package com.ejianc.business.prjdocs.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 投入资源需求计划--设备计划
 * 
 * @author generator
 * 
 */
public class PrjInvestResourceRequirePlanEquipmentVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long pid; // 父id
    private Long equipmentId; // 设备id
    private String equipmentName; // 设备名称
    private Integer equipmentNumber; // 设备数量
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date arrivalTime; // 到位时间
    private String otherExplain; // 其他说明

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }

    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public Integer getEquipmentNumber() {
        return equipmentNumber;
    }

    public void setEquipmentNumber(Integer equipmentNumber) {
        this.equipmentNumber = equipmentNumber;
    }
    public Date getArrivalTime() {
        return arrivalTime;
    }

    public void setArrivalTime(Date arrivalTime) {
        this.arrivalTime = arrivalTime;
    }
    public String getOtherExplain() {
        return otherExplain;
    }

    public void setOtherExplain(String otherExplain) {
        this.otherExplain = otherExplain;
    }
    
}
